==> jc-1.4.0.tar.gz: gnu/xml/transform/ApplyTemplatesNode.h <==
// final class gnu.xml.transform.ApplyTemplatesNode

// class file dependencies
// @dep_class 409c4b872d4005ca gnu_xml_transform_ApplyTemplatesNode
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_transform_TemplateNode

#include "gnu/xml/transform/TemplateNode.h"

#ifndef _JC_gnu_xml_transform_ApplyTemplatesNode_H_
#define _JC_gnu_xml_transform_ApplyTemplatesNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_ApplyTemplatesNode$sub_refs	_jc_gnu_xml_transform_ApplyTemplatesNode$sub_refs;
typedef struct _jc_gnu_xml_transform_ApplyTemplatesNode$sub_nonrefs	_jc_gnu_xml_transform_ApplyTemplatesNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_ApplyTemplatesNode$refs	_jc_gnu_xml_transform_ApplyTemplatesNode$refs;
typedef struct _jc_gnu_xml_transform_ApplyTemplatesNode$nonrefs	_jc_gnu_xml_transform_ApplyTemplatesNode$nonrefs;
typedef struct _jc_gnu_xml_transform_ApplyTemplatesNode$object	_jc_gnu_xml_transform_ApplyTemplatesNode$object;

typedef const struct _jc_gnu_xml_transform_ApplyTemplatesNode$vmethods	_jc_gnu_xml_transform_ApplyTemplatesNode$vmethods;
typedef const struct _jc_gnu_xml_transform_ApplyTemplatesNode$vtable	_jc_gnu_xml_transform_ApplyTemplatesNode$vtable;
typedef const struct _jc_gnu_xml_transform_ApplyTemplatesNode$vtype	_jc_gnu_xml_transform_ApplyTemplatesNode$vtype;

// Constructors
extern void _jc_gnu_xml_transform_ApplyTemplatesNode$method$_init$0fe1b3e674eed433(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_xpath_Expr$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, struct _jc_object *, jboolean);

// Virtual methods
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_ApplyTemplatesNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
extern void _jc_gnu_xml_transform_ApplyTemplatesNode$method$doApply$85a30cd55d4e7167(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_ApplyTemplatesNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_ApplyTemplatesNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_ApplyTemplatesNode$method_info$doApply$85a30cd55d4e7167;
extern _jc_method _jc_gnu_xml_transform_ApplyTemplatesNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_transform_ApplyTemplatesNode$vmethods {
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
	void	(*doApply$85a30cd55d4e7167)(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *);
};

// Vtable
struct _jc_gnu_xml_transform_ApplyTemplatesNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
	_jc_gnu_xml_transform_ApplyTemplatesNode$vmethods	gnu_xml_transform_ApplyTemplatesNode;
};

// Vtype
struct _jc_gnu_xml_transform_ApplyTemplatesNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_ApplyTemplatesNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_ApplyTemplatesNode$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*select;
	struct _jc_javax_xml_namespace_QName$object	*mode;
	struct _jc_object	*sortKeys;
	struct _jc_object	*withParams;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_ApplyTemplatesNode$refs {
    _jc_gnu_xml_transform_ApplyTemplatesNode$sub_refs	gnu_xml_transform_ApplyTemplatesNode;
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_ApplyTemplatesNode$sub_nonrefs {
	jboolean	isDefault;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_ApplyTemplatesNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
    _jc_gnu_xml_transform_ApplyTemplatesNode$sub_nonrefs	gnu_xml_transform_ApplyTemplatesNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_ApplyTemplatesNode$object {
	_jc_gnu_xml_transform_ApplyTemplatesNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_ApplyTemplatesNode$vtype	*vtype;
	_jc_gnu_xml_transform_ApplyTemplatesNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_ApplyTemplatesNode$vtype _jc_gnu_xml_transform_ApplyTemplatesNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_ApplyTemplatesNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_ApplyTemplatesNode$class_object;

#endif	/* _JC_gnu_xml_transform_ApplyTemplatesNode_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/ApplyTemplatesNode.h <==
// final class gnu.xml.transform.ApplyTemplatesNode

// class file dependencies
// @dep_class 409c4b872d4005ca gnu_xml_transform_ApplyTemplatesNode
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_transform_TemplateNode

#include "gnu/xml/transform/TemplateNode.h"

#ifndef _JC_gnu_xml_transform_ApplyTemplatesNode_H_
#define _JC_gnu_xml_transform_ApplyTemplatesNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_ApplyTemplatesNode$sub_refs	_jc_gnu_xml_transform_ApplyTemplatesNode$sub_refs;
typedef struct _jc_gnu_xml_transform_ApplyTemplatesNode$sub_nonrefs	_jc_gnu_xml_transform_ApplyTemplatesNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_ApplyTemplatesNode$refs	_jc_gnu_xml_transform_ApplyTemplatesNode$refs;
typedef struct _jc_gnu_xml_transform_ApplyTemplatesNode$nonrefs	_jc_gnu_xml_transform_ApplyTemplatesNode$nonrefs;
typedef struct _jc_gnu_xml_transform_ApplyTemplatesNode$object	_jc_gnu_xml_transform_ApplyTemplatesNode$object;

typedef const struct _jc_gnu_xml_transform_ApplyTemplatesNode$vmethods	_jc_gnu_xml_transform_ApplyTemplatesNode$vmethods;
typedef const struct _jc_gnu_xml_transform_ApplyTemplatesNode$vtable	_jc_gnu_xml_transform_ApplyTemplatesNode$vtable;
typedef const struct _jc_gnu_xml_transform_ApplyTemplatesNode$vtype	_jc_gnu_xml_transform_ApplyTemplatesNode$vtype;

// Constructors
extern void _jc_gnu_xml_transform_ApplyTemplatesNode$method$_init$0fe1b3e674eed433(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_xpath_Expr$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_ApplyTemplatesNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_transform_ApplyTemplatesNode$method$doApply$85a30cd55d4e7167(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_ApplyTemplatesNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_ApplyTemplatesNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_ApplyTemplatesNode$method_info$doApply$85a30cd55d4e7167;
extern _jc_method _jc_gnu_xml_transform_ApplyTemplatesNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_transform_ApplyTemplatesNode$vmethods {
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
	void	(*doApply$85a30cd55d4e7167)(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_transform_ApplyTemplatesNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_ApplyTemplatesNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
	_jc_gnu_xml_transform_ApplyTemplatesNode$vmethods	gnu_xml_transform_ApplyTemplatesNode;
};

// Vtype
struct _jc_gnu_xml_transform_ApplyTemplatesNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_ApplyTemplatesNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_ApplyTemplatesNode$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*select;
	struct _jc_javax_xml_namespace_QName$object	*mode;
	struct _jc_object	*sortKeys;
	struct _jc_object	*withParams;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_ApplyTemplatesNode$refs {
    _jc_gnu_xml_transform_ApplyTemplatesNode$sub_refs	gnu_xml_transform_ApplyTemplatesNode;
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_ApplyTemplatesNode$sub_nonrefs {
	jboolean	isDefault;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_ApplyTemplatesNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
    _jc_gnu_xml_transform_ApplyTemplatesNode$sub_nonrefs	gnu_xml_transform_ApplyTemplatesNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_ApplyTemplatesNode$object {
	_jc_gnu_xml_transform_ApplyTemplatesNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_ApplyTemplatesNode$vtype	*vtype;
	_jc_gnu_xml_transform_ApplyTemplatesNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_ApplyTemplatesNode$vtype _jc_gnu_xml_transform_ApplyTemplatesNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_ApplyTemplatesNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_ApplyTemplatesNode$class_object;

#endif	/* _JC_gnu_xml_transform_ApplyTemplatesNode_H_ */
